@@ -33,7 +33,7 @@ class Condition:
             sql += " "
             sql += self.__logic
             sql += ","
-        sql = [0: -1]
+        sql = sql[0: -1]
         sql += ")"
         return sql
     
